function [tstruct, varargout] = BI(y, x, ainu)
%Solves least squares problem using Chave-Thomson bounded influence algorithm
%input variables
% y - n by 1 response vector (required)
% x - n by p predictor matrix (required)
%ainu - leverage point weighting scale factor
%output variables
%tstruct - structure containing number of iterations and regression
%          parameters, se, t-stistic and p-value for each
%rstruct - structure containing regression residuals, weights and
%          normalized sum of squared residuals for each iteration
%pstruct - structure containing  r^2, and anova, runs test and Durbin-Watson test
%          p-values for each iteration
n = length(y);
p = size(x, 2);
w = ones(size(y));
[b bse t tprob] = Treg(y, x, w);
r = y - x*b;
d = iqr(r)/1.34903;
ovar = r'*r/n;
rss = ovar;
what = ones(size(y));
wsum = n;
swhat = exp(-0.3068528*exp(-ainu^2));
hat = diag(x*inv(x'*x)*x');
bs = b;
bses = bse;
ts = t;
tprobs = tprob;
rs =[];
ws =[];
whats = [];
r2 =[];
apval = [];
rpval = [];
dwpval = [];
for k = 1:15
     wh = 1./max(1, abs(r)/(1.5*d));
     ws(:, k) = wh;
     t1 = ainu*(wsum*hat/2 - ainu);
     what = what.*exp(-0.3068528*exp(t1))/swhat;
     whats(:, k) = what;
     w = wh.*what;
     a = Anovar(y, x, w);
     r2 = [r2 a(1,2)/a(3,2)];
     apval = [apval a(1, 5)];
     [b bse t tprob] = Treg(y, x, w);
     bs = [bs b];
     bses = [bses bse];
     ts = [ts t];
     tprobs = [tprobs tprob];
     [h, pval] = runstest(w.*r);
     rpval =[rpval pval];
     wx = repmat(w, 1, p).*x;
     pval = dwtest(w.*r, wx);
     dwpval = [dwpval pval];
     hat = diag(wx*inv(wx'*wx)*wx');
     jj = find(w ~= 0);
     r = y - x*b;
     rs(:, k) = r;
     d = iqr(r(jj))/1.34903;
     wsum = sum(w);
     nvar = sum((w.*r).^2)/wsum;
     rss = [rss nvar];
     if abs(nvar - ovar) <= 0.02*ovar
        break
     end
     ovar = nvar;
end
tstruct.b = bs;
tstruct.bse = bses;
tstruct.t = ts;
tstruct.pval = tprobs;
if nargout > 1
    rstruct.res = rs;
    rstruct.w = ws;
    rstruct.what = whats;
    rstruct.rss = rss;
    varargout{1} = rstruct;
    varargout{2} = [];
end
if nargout > 2
    pstruct.r2 = r2;
    pstruct.anova = apval;
    pstruct.runs = rpval;
    pstruct.dw = dwpval;
    varargout{2} = pstruct;
end
end

