function [Cf] = Padesum(s)
%Computes sum from 1 to n of s(i) using Pade approximant implemented with
%continued fraction expansion; see Z. Naturforschung, 33a, 402-417, 1978.
%
%Input variable
%s--series of values to be summed, may be complex
%Output variable
%Cf--sum of the series
%
n = length(s);
D = [];
x = zeros(1,n);
d = [];
t = zeros(1,n);
D(1) = s(1);
d(1) = D(1);
if n == 1
    Cf = d(1);
    return
end
D(2) = s(2);
d(2) = -D(2)/D(1);
if n == 2
    Cf = d(1)/(1 + d(2));
    return
end
for i = 3:n
    L = 2*fix((i - 1)/2);
    %update x vector
    x(L:-2:4) = x(L - 1:-2:3) + d(i - 1)*x(L - 2:-2:2);
    x(2) = x(1) + d(i - 1);
    % interchange odd and even parts
    t(1:2:L -1) = x(1:2:L - 1);
    x(1:2:L - 1) = x(2:2:L);
    x(2:2:L) = t(1:2:L - 1);
    % compute cf coefficient
    D(i) = s(i) + s(i - 1:-1:i - L/2)*(x(1:2:L - 1)).';
    d(i) = -D(i)/D(i - 1);
end
%evaluate continued fraction
Cf = 1;
for k = n:-1:2
    Cf = 1 + d(k)/Cf;
end
Cf = d(1)/Cf;
end

